@@ -13,6 +13,6 @@ function(x,nv,col,mb,crit="f2")
 	res<-numeric(2)
   	res<-.Fortran("rs_bos",res=as.double(res),x=as.matrix(x),
 	     as.integer(nv),as.double(col),as.integer(m),as.integer(n),
-	     as.integer(mb),as.integer(critn),package="stima")$res
+	     as.integer(mb),as.integer(critn),PACKAGE="stima")$res
 	return(res)
 }
