@@ -7,6 +7,6 @@ function(x,y)
 		print("Length Error")
 	else
 		corr<-.Fortran("rs_cor",corr=as.double(0),
-		               as.double(x),as.double(y),as.integer(n),package="stima")$corr
+		               as.double(x),as.double(y),as.integer(n),PACKAGE="stima")$corr
 	return(corr)
 }
